import redis
import logging

from .preprocess import preprocess_file


logger = logging.getLogger(__name__)


def run_daemon(config, host, port, listen_queue, write_queue):
    """ Run the preprocessing daemon, listening on a redis queue
        for files to be preprocessed. After preprocessing the filename
        of the preprocessed files will be pushed to the output queue.
    """
    # initialize the queue client
    client = redis.Redis(
        host=host, port=port, charset="utf-8", decode_responses=True
    )
    logger.debug("waiting for redis queue '%s'..." % listen_queue)
    while True:
        # fetch an item from the queue to be preprocessed
        value = client.brpop(listen_queue)[0]

        # start the preprocessing on that file
        filenames = preprocess_file(config, value)
        # TODO: convert to string, list, ....

        # write the filenames to the queue
        client.lpush(write_queue, filenames)
